@@ -67,7 +67,10 @@ class thread_ctx_t
     thread_ctx_t ();
 
     //  Start a new thread with proper scheduling parameters.
-    void start_thread (thread_t &thread_, thread_fn *tfn_, void *arg_) const;
+    void start_thread (thread_t &thread_,
+                       thread_fn *tfn_,
+                       void *arg_,
+                       const char *name_ = NULL) const;
 
     int set (int option_, int optval_);
     int get (int option_);
