@@ -54,7 +54,7 @@ const zmq::epoll_t::epoll_fd_t zmq::epoll_t::epoll_retired_fd =
 zmq::epoll_t::epoll_t (const zmq::thread_ctx_t &ctx_) :
     worker_poller_base_t (ctx_)
 {
-#ifdef ZMQ_USE_EPOLL_CLOEXEC
+#ifdef ZMQ_IOTHREAD_POLLER_USE_EPOLL_CLOEXEC
     //  Setting this option result in sane behaviour when exec() functions
     //  are used. Old sockets are closed and don't block TCP ports, avoid
     //  leaks, etc.
@@ -75,8 +75,8 @@ zmq::epoll_t::~epoll_t ()
 #else
     close (_epoll_fd);
 #endif
-    for (retired_t::iterator it = _retired.begin (); it != _retired.end ();
-         ++it) {
+    for (retired_t::iterator it = _retired.begin (), end = _retired.end ();
+         it != end; ++it) {
         LIBZMQ_DELETE (*it);
     }
 }
@@ -112,9 +112,7 @@ void zmq::epoll_t::rm_fd (handle_t handle_)
     int rc = epoll_ctl (_epoll_fd, EPOLL_CTL_DEL, pe->fd, &pe->ev);
     errno_assert (rc != -1);
     pe->fd = retired_fd;
-    _retired_sync.lock ();
     _retired.push_back (pe);
-    _retired_sync.unlock ();
 
     //  Decrease the load metric of the thread.
     adjust_load (-1);
@@ -209,13 +207,11 @@ void zmq::epoll_t::loop ()
         }
 
         //  Destroy retired event sources.
-        _retired_sync.lock ();
-        for (retired_t::iterator it = _retired.begin (); it != _retired.end ();
-             ++it) {
+        for (retired_t::iterator it = _retired.begin (), end = _retired.end ();
+             it != end; ++it) {
             LIBZMQ_DELETE (*it);
         }
         _retired.clear ();
-        _retired_sync.unlock ();
     }
 }
 
