@@ -222,8 +222,8 @@ void zmq::udp_engine_t::plug (io_thread_t *io_thread_, session_base_t *session_)
         bool multicast = udp_addr->is_mcast ();
 
         if (multicast) {
-        //  Multicast addresses should be allowed to bind to more than
-        //  one port as all ports should receive the message
+            //  Multicast addresses should be allowed to bind to more than
+            //  one port as all ports should receive the message
 #ifdef SO_REUSEPORT
             rc = setsockopt (_fd, SOL_SOCKET, SO_REUSEPORT,
                              reinterpret_cast<char *> (&on), sizeof (on));
@@ -396,8 +396,8 @@ void zmq::udp_engine_t::out_event ()
     if (rc == 0) {
         msg_t body_msg;
         rc = _session->pull_msg (&body_msg);
-        //  TODO rc is not checked here. We seem to assume rc == 0. An
-        //  assertion should be added.
+        //  If there's a group, there should also be a body
+        errno_assert (rc == 0);
 
         const size_t group_size = group_msg.size ();
         const size_t body_size = body_msg.size ();
@@ -412,7 +412,7 @@ void zmq::udp_engine_t::out_event ()
                 rc = group_msg.close ();
                 errno_assert (rc == 0);
 
-                body_msg.close ();
+                rc = body_msg.close ();
                 errno_assert (rc == 0);
 
                 return;
