@@ -97,3 +97,10 @@ static inline int poll (struct pollfd *pfd, unsigned long nfds, int timeout)
 #define AI_NUMERICSERV 0x0400
 #endif
 #endif
+
+//  In MSVC prior to v14, snprintf is not available
+//  The closest implementation is the _snprintf_s function
+#if defined(_MSC_VER) && _MSC_VER < 1900
+#define snprintf(buffer_, count_, format_, ...)                                \
+    _snprintf_s (buffer_, count_, _TRUNCATE, format_, __VA_ARGS__)
+#endif
