@@ -19,11 +19,18 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <unity.h>
 #include "../tests/testutil.hpp"
+#include "../tests/testutil_unity.hpp"
 #include "../unittests/unittest_resolver_common.hpp"
 
 #include <ip_resolver.hpp>
 #include <ip.hpp>
 
+#ifndef _WIN32
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netdb.h>
+#endif
+
 void setUp ()
 {
 }
@@ -61,7 +68,7 @@ class test_ip_resolver_t : public zmq::ip_resolver_t
         unsigned lut_len = sizeof (dns_lut) / sizeof (dns_lut[0]);
         struct addrinfo ai;
 
-        assert (service_ == NULL);
+        TEST_ASSERT_NULL (service_);
 
         bool ipv6 = (hints_->ai_family == AF_INET6);
         bool no_dns = (hints_->ai_flags & AI_NUMERICHOST) != 0;
@@ -150,10 +157,11 @@ static void test_resolve (zmq::ip_resolver_options_t opts_,
     int rc = resolver.resolve (&addr, name_);
 
     if (expected_addr_ == NULL) {
+        // TODO also check the expected errno
         TEST_ASSERT_EQUAL (-1, rc);
         return;
     } else {
-        TEST_ASSERT_EQUAL (0, rc);
+        TEST_ASSERT_SUCCESS_ERRNO (rc);
     }
 
     validate_address (family, &addr, expected_addr_, expected_port_,
@@ -803,9 +811,7 @@ static void test_addr (int family_, const char *addr_, bool multicast_)
     test_ip_resolver_t resolver (resolver_opts);
     zmq::ip_addr_t addr;
 
-    int rc = resolver.resolve (&addr, addr_);
-
-    assert (rc == 0);
+    TEST_ASSERT_SUCCESS_ERRNO (resolver.resolve (&addr, addr_));
 
     TEST_ASSERT_EQUAL (family_, addr.family ());
     TEST_ASSERT_EQUAL (multicast_, addr.is_multicast ());
