@@ -4,18 +4,19 @@
 #include <Windows.h>
 #endif
 
+#include <assert.h>
 #include <stdlib.h>
 
 #include "mutex.h"
 
-typedef struct zmq_raw_mutex
+struct zmq_raw_mutex
 {
 #ifdef _WIN32
 	CRITICAL_SECTION m;
 #else
 	pthread_mutex_t m;
 #endif
-} zmq_raw_mutex;
+};
 
 
 zmq_raw_mutex *zmq_raw_mutex_create()
@@ -24,7 +25,8 @@ zmq_raw_mutex *zmq_raw_mutex_create()
 	#ifdef _WIN32
 	InitializeCriticalSection (&m->m);
 	#else
-	pthread_mutex_init (&m->m, NULL);
+	int rc = pthread_mutex_init (&m->m, NULL);
+	assert (rc == 0);
 	#endif
 	return m;
 }
@@ -34,7 +36,8 @@ void zmq_raw_mutex_destroy (zmq_raw_mutex *m)
 	#ifdef _WIN32
 	DeleteCriticalSection (&m->m);
 	#else
-	pthread_mutex_destroy (&m->m);
+	int rc = pthread_mutex_destroy (&m->m);
+	assert (rc == 0);
 	#endif
 	free (m);
 }
@@ -44,7 +47,8 @@ void zmq_raw_mutex_lock (zmq_raw_mutex *m)
 	#ifdef _WIN32
 	EnterCriticalSection (&m->m);
 	#else
-	pthread_mutex_lock (&m->m);
+	int rc = pthread_mutex_lock (&m->m);
+	assert (rc == 0);
 	#endif
 }
 
@@ -53,7 +57,8 @@ void zmq_raw_mutex_unlock (zmq_raw_mutex *m)
 	#ifdef _WIN32
 	LeaveCriticalSection (&m->m);
 	#else
-	pthread_mutex_unlock (&m->m);
+	int rc = pthread_mutex_unlock (&m->m);
+	assert (rc == 0);
 	#endif
 }
 
